class Gestorh::FolhaAgrupadaIdSeparado < Gestorh::GestorhRecord
  self.table_name = 'public.folhas_agrupadas_gestorh_folha_id_separado'

  belongs_to :funcionario, foreign_key: :matricula, primary_key: :fn_matricula

  belongs_to :vinculo, foreign_key: :mvps_vinculo, primary_key: :vc_codigo
  belongs_to :funcao, foreign_key: :mvps_funcao, primary_key: :fc_codigo
  belongs_to :cargo, foreign_key: :mvps_cargo, primary_key: :fc_codigo, class_name: 'Gestorh::Funcao'
  belongs_to :lotacao, foreign_key: :mvps_reglotacao, primary_key: :lt_registro
  belongs_to :nivel_salario, foreign_key: :mvps_nivelsalario, primary_key: :ns_registro

  def liquido_total
    self.rendimento_total - self.desconto_total
  end

  def eventos_e_valores
    # .where.not('cdclassificacaoverba.cv_classificacao': 'DESCONTO_PREVIDENCIA_PUBLICA_IAPEP')
    Gestorh::MovimentoAcumulado.where(mv_regfolha: self.folhas, mv_matricula: self.matricula)
      .joins(verba: :classificacao_verba)
      .select('mv_regfolha as folha_id', 'mv_verba as codigo_evento',
        'cdverba.vb_nome as nome_evento',
        'mv_dc as status', 'mv_total as valor',
        'cdclassificacaoverba.cv_classificacao as tipo')
      .to_a
      .uniq{|x| [x.codigo_evento, x.status, x.valor] } # uniq temporario para remover verbas com 2 classificacoes
  end

  def remuneracao_paradigma
    if Date.new(ano, mes, 1) < Date.new(2013,7,1)
      self.eventos_e_valores.select{|x| x.tipo == 'RENDIMENTO_REMUNERACAO' && x.status == 'C'}
    else
      []
    end
  end

  def vantagens_pessoais
    self.eventos_e_valores.select{|x| x.tipo == 'RENDIMENTO_VANTAGENS_PESSOAIS' && x.status == 'C'}
  end

  def subsidios
    if Date.new(ano, mes, 1) < Date.new(2013,7,1)
      []
    else
      self.eventos_e_valores.select{|x| (x.tipo == 'RENDIMENTO_SUBSIDIO_DIFERENCA_FUNCAO' ||  x.tipo == 'RENDIMENTO_REMUNERACAO') && x.status == 'C'}
    end
  end

  def indenizacoes
    self.eventos_e_valores.select{|x| x.tipo == 'RENDIMENTO_INDENIZACOES' && x.status == 'C' }
  end

  def vantagens_eventuais
    self.eventos_e_valores.select{|x| x.tipo == 'RENDIMENTO_VANTAGENS_EVENTUAIS' && x.status == 'C'}
  end

  def gratificacoes
    self.eventos_e_valores.select{|x| x.tipo == 'RENDIMENTO_GRATIFICACOES' && x.status == 'C'}
  end

  # sobrou da show
  def subsidio_vantagens_pessoais
    self.eventos_e_valores.select{|x| x.tipo == 'RENDIMENTO_VANTAGENS_EVENTUAIS' || x.tipo == 'RENDIMENTO_VANTAGENS_PESSOAIS'}
  end

  def subsidio_vantagens_pessoais_eventuais
    self.eventos_e_valores.select{|x| x.tipo == 'RENDIMENTO_SUBSIDIO_DIFERENCA_FUNCAO' ||
      x.tipo == 'RENDIMENTO_VANTAGENS_PESSOAIS' || (x.tipo == 'RENDIMENTO_VANTAGENS_EVENTUAIS' && x.status == 'C')}
  end

  # diarias
  def diarias
    self.daily_rates.where(date: [Date.new(self.ano, self.mes)..Date.new(self.ano, self.mes).at_end_of_month])
      .sum(:pago)
  end

  def diarias_positivas
    self.daily_rates.where(pago: [0..Float::INFINITY], date: [Date.new(self.ano, self.mes)..Date.new(self.ano, self.mes).at_end_of_month])
        .sum(:pago)
  end

  def diarias_negativas
    self.daily_rates.where(pago: [-Float::INFINITY..0], date: [Date.new(self.ano, self.mes)..Date.new(self.ano, self.mes).at_end_of_month])
        .sum(:pago)
  end
end
